[Python-checkins] r43687 - python/branches/release24-maint/Lib/test/test_curses.py

anthony.baxter python-checkins at python.org
Thu Apr 6 09:15:08 CEST 2006


Author: anthony.baxter
Date: Thu Apr  6 09:15:06 2006
New Revision: 43687

Modified:
   python/branches/release24-maint/Lib/test/test_curses.py
Log:
backport: 
In some environments (under screen, in a chroot) curses doesn't support
mouse events. This makes the test fail. Catch that case and don't run
the tests. Should make the debian/ubuntu buildbots that run in a chroot
work again. 


Modified: python/branches/release24-maint/Lib/test/test_curses.py
==============================================================================
--- python/branches/release24-maint/Lib/test/test_curses.py	(original)
+++ python/branches/release24-maint/Lib/test/test_curses.py	Thu Apr  6 09:15:06 2006
@@ -201,11 +201,13 @@
         curses.has_key(13)
 
     if hasattr(curses, 'getmouse'):
-        curses.mousemask(curses.BUTTON1_PRESSED)
-        curses.mouseinterval(10)
-        # just verify these don't cause errors
-        m = curses.getmouse()
-        curses.ungetmouse(*m)
+        (availmask, oldmask) = curses.mousemask(curses.BUTTON1_PRESSED)
+        # availmask indicates that mouse stuff not available.
+        if availmask != 0:
+            curses.mouseinterval(10)
+            # just verify these don't cause errors
+            m = curses.getmouse()
+            curses.ungetmouse(*m)
 
 def unit_tests():
     from curses import ascii


More information about the Python-checkins mailing list